# Transmission-rpc Readme

[![PyPI](https://img.shields.io/pypi/v/transmission-rpc)](https://pypi.org/project/transmission-rpc/)
[![Documentation Status](https://readthedocs.org/projects/transmission-rpc/badge/?version=stable)](https://transmission-rpc.readthedocs.io/en/stable/?badge=stable)
[![ci](https://github.com/Trim21/transmission-rpc/workflows/ci/badge.svg)](https://github.com/Trim21/transmission-rpc/actions)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/transmission-rpc)](https://pypi.org/project/transmission-rpc/)
[![Codecov branch](https://img.shields.io/codecov/c/github/Trim21/transmission-rpc/master)](https://codecov.io/gh/Trim21/transmission-rpc/branch/master)

`transmission-rpc` is hosted by GitHub at [github.com/Trim21/transmission-rpc](https://github.com/Trim21/transmission-rpc)

## Introduction

`transmission-rpc` is a python module implementing the json-rpc client protocol for the BitTorrent client Transmission.

## Install

```bash
$ pip install transmission-rpc==3.0.0a3
```

## Documents

<https://transmission-rpc.readthedocs.io/>

## Developer

this project is forked from https://bitbucket.org/blueluna/transmissionrpc/overview

`transmission-rpc` is licensed under the MIT license.

Copyright (c) 2018-2020 Trim21

Copyright (c) 2008-2014 Erik Svensson
